@@ -1,11 +1,10 @@
-
 from . import (
     code_blocks, headings, plain_summary, featured_image, media, tables,
-    authors
+    authors, outdated_article,
 )
 
 
 PLUGINS = [
     code_blocks, headings, plain_summary, featured_image, media, tables,
-    authors
+    authors, outdated_article
 ]
