@@ -1,5 +1,4 @@
-
-from pelican import signals
+from pelican import signals, contents
 
 from .utils import modify_html
 
@@ -9,7 +8,7 @@ def register():
 
 
 def process_code_blocks(content):
-    if not content.source_path.endswith('.md'):
+    if not isinstance(content, contents.Article):
         return
 
     with modify_html(content) as html_tree:
