@@ -1,7 +1,6 @@
-
 import os
 
-from pelican import signals
+from pelican import signals, contents
 
 from .utils import modify_html
 
@@ -11,7 +10,7 @@ def register():
 
 
 def attach_featured_image(content):
-    if not content.source_path.endswith('.md'):
+    if not isinstance(content, contents.Article):
         return
 
     image = getattr(content, 'image', None)
@@ -25,6 +24,6 @@ def attach_featured_image(content):
                     image = os.path.join(content.settings['SITEURL'], image)
 
     if image:
-        content.image = image.format(filename=content.get_siteurl())
+        content.image = image.format(static=content.get_siteurl())
     else:
         content.image = None
