@@ -1,6 +1,5 @@
-
 from lxml import etree
-from pelican import signals
+from pelican import signals, contents
 
 from .utils import modify_html
 
@@ -10,7 +9,7 @@ def register():
 
 
 def enhance_headings(content):
-    if not content.source_path.endswith('.md'):
+    if not isinstance(content, contents.Article):
         return
 
     with modify_html(content) as html_tree:
